Documentation
¶
Overview ¶
Package pql provides a Pipeline Query Language that can be translated into SQL.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CompileOptions ¶
type CompileOptions struct {
// Parameters is a map of identifiers to SQL snippets to substitute in.
// For example, a "foo": "$1" entry would replace unquoted "foo" identifiers
// with "$1" in the resulting SQL.
Parameters map[string]string
}
CompileOptions a set of optional parameters that configure compilation. nil is treated the same as the zero value.
Click to show internal directories.
Click to hide internal directories.